@@ -239,7 +239,6 @@ OC.L10N.register(
     "Select conversation" : "Seleccionar conversación",
     "on" : "el",
     "at" : "a las",
-    "Reminder" : "Recordatorio",
     "before at" : "antes a las",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
@@ -250,7 +249,6 @@ OC.L10N.register(
     "Edit time" : "Editar hora",
     "Save time" : "Guardar hora",
     "Remove reminder" : "Eliminar recordatorio",
-    "+ Add reminder" : "+ Agregar recordatorio",
     "Add reminder" : "Agregar recordatorio",
     "seconds" : "segundos",
     "minutes" : "minutos",
@@ -278,14 +276,16 @@ OC.L10N.register(
     "Checking availability" : "Verificando disponibilidad",
     "Has not responded to {organizerName}'s invitation yet" : "No ha respondido a la invitación de {organizerName} aún",
     "{organizer} (organizer)" : "{organizer} (organizador)",
+    "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y salas",
+    "Legend" : "Leyenda",
+    "Out of office" : "Fuera de la oficina",
+    "Attendees:" : "Asistentes:",
+    "Done" : "Hecho",
+    "Room name" : "Nombre de la sala",
     "Free" : "Disponible",
     "Busy (tentative)" : "Ocupado (tentativo)",
     "Busy" : "Ocupado",
-    "Out of office" : "Fuera de la oficina",
     "Unknown" : "Desconocido",
-    "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y salas",
-    "Done" : "Hecho",
-    "Room name" : "Nombre de la sala",
     "The invitation has been accepted successfully." : "La invitación se aceptó correctamente.",
     "Failed to accept the invitation." : "No se pudo aceptar la invitación.",
     "The invitation has been declined successfully." : "La invitación se rechazó correctamente.",
@@ -313,7 +313,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar la configuración de todo el día para eventos que forman parte de un conjunto de repeticiones.",
     "From" : "De",
     "To" : "A",
-    "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "_time_::_times_" : ["hora","veces","veces"],
     "never" : "nunca",
@@ -336,7 +335,7 @@ OC.L10N.register(
     "Does not repeat" : "No se repite",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definición de recurrencia de este evento no es completamente compatible con Nextcloud. Si editas las opciones de recurrencia, es posible que se pierdan ciertas repeticiones.",
     "No rooms or resources yet" : "Aún no hay salas o recursos",
-    "Suggestions" : "Sugerencias",
+    "Resources" : "Recursos",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asiento","{seatingCapacity} asientos","{seatingCapacity} asientos"],
     "Add resource" : "Agregar recurso",
     "Has a projector" : "Tiene proyector",
@@ -391,15 +390,15 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que tu zona horaria es UTC.\n      Esto es probablemente el resultado de medidas de seguridad de tu navegador web.\n      Por favor, establece tu zona horaria manualmente en la configuración del calendario.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró tu zona horaria configurada ({timezoneId}). Se usará UTC.\n      Por favor, cambia tu zona horaria en la configuración y reporta este problema.",
+    "Edit event" : "Editar evento",
     "Event does not exist" : "El evento no existe",
     "Duplicate" : "Duplicar",
     "Delete this occurrence" : "Eliminar esta ocurrencia",
     "Delete this and all future" : "Eliminar esta y todas las siguientes",
-    "Details" : "Detalles",
+    "All day" : "Todo el día",
     "Managing shared access" : "Gestionar acceso compartido",
     "Deny access" : "Denegar acceso",
     "Invite" : "Invitar",
-    "Resources" : "Recursos",
     "_User requires access to your file_::_Users require access to your file_" : ["El usuario necesita acceso a tu archivo","Los usuarios necesitan acceso a tu archivo","Los usuarios necesitan acceso a tu archivo"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["El adjunto requiere acceso compartido","Los adjuntos requieren acceso compartido","Los adjuntos requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
@@ -493,6 +492,10 @@ OC.L10N.register(
     "Imported {filename}" : "Importado {filename}",
     "This is an event reminder." : "Esto es un recordatorio de evento.",
     "Appointment not found" : "Cita no encontrada",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Reminder" : "Recordatorio",
+    "+ Add reminder" : "+ Agregar recordatorio",
+    "Suggestions" : "Sugerencias",
+    "Details" : "Detalles"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
